@@ -39,7 +39,6 @@ import org.apache.cxf.management.annotation.ManagedOperation;
 import org.apache.cxf.management.annotation.ManagedOperationParameter;
 import org.apache.cxf.management.annotation.ManagedOperationParameters;
 import org.apache.cxf.management.annotation.ManagedResource;
-import org.apache.cxf.ws.addressing.EndpointReferenceType;
 import org.apache.cxf.ws.rm.DestinationSequence.DeferredAcknowledgment;
 import org.apache.cxf.ws.rm.v200702.Identifier;
 import org.apache.cxf.ws.rm.v200702.SequenceAcknowledgement.AcknowledgementRange;
@@ -54,35 +53,30 @@ public class ManagedRMEndpoint implements ManagedComponent {
 
     private static final String[] SOURCE_SEQUENCE_NAMES = 
     {"sequenceId", "currentMessageNumber", "expires", "lastMessage", "queuedMessageCount", 
-     "target", "wsrm", "wsa"};
+     "target"};
     private static final String[] SOURCE_SEQUENCE_DESCRIPTIONS = SOURCE_SEQUENCE_NAMES;
-    @SuppressWarnings("rawtypes") // needed as OpenType isn't generic on Java5
     private static final OpenType[] SOURCE_SEQUENCE_TYPES =  
     {SimpleType.STRING, SimpleType.LONG, SimpleType.DATE, SimpleType.BOOLEAN, SimpleType.INTEGER, 
-     SimpleType.STRING, SimpleType.STRING, SimpleType.STRING};
+     SimpleType.STRING};
     
     private static final String[] DESTINATION_SEQUENCE_NAMES = 
-    {"sequenceId", "lastMessageNumber", "correlationId", "ackTo", "wsrm", "wsa"};
+    {"sequenceId", "lastMessageNumber", "correlationId", "ackTo"};
     private static final String[] DESTINATION_SEQUENCE_DESCRIPTIONS = DESTINATION_SEQUENCE_NAMES;
-    @SuppressWarnings("rawtypes") // needed as OpenType isn't generic on Java5
     private static final OpenType[] DESTINATION_SEQUENCE_TYPES =  
     {SimpleType.STRING, SimpleType.LONG, SimpleType.STRING, 
-     SimpleType.STRING, SimpleType.STRING, SimpleType.STRING};
+     SimpleType.STRING};
 
-    private static final String[] RETRY_STATUS_NAMES = 
-    {"messageNumber", "retries", "maxRetries", "previous", "next", "nextInterval", 
-     "backOff", "pending", "suspended"};
-    private static final String[] RETRY_STATUS_DESCRIPTIONS = RETRY_STATUS_NAMES;
-    @SuppressWarnings("rawtypes") // needed as OpenType isn't generic on Java5
-    private static final OpenType[] RETRY_STATUS_TYPES =  
-    {SimpleType.LONG, SimpleType.INTEGER, SimpleType.INTEGER, SimpleType.DATE, 
-     SimpleType.DATE, SimpleType.LONG, SimpleType.LONG, 
+    private static final String[] RETRANSMISSION_STATUS_NAMES = 
+    {"messageNumber", "resends", "previous", "next", "nextInterval", "backOff", "pending", "suspended"};
+    private static final String[] RETRANSMISSION_STATUS_DESCRIPTIONS = RETRANSMISSION_STATUS_NAMES;
+    private static final OpenType[] RETRANSMISSION_STATUS_TYPES =  
+    {SimpleType.LONG, SimpleType.INTEGER, SimpleType.DATE, SimpleType.DATE, SimpleType.LONG, SimpleType.LONG, 
      SimpleType.BOOLEAN, SimpleType.BOOLEAN};
 
     private static CompositeType sourceSequenceType;
     private static CompositeType destinationSequenceType;
 
-    private static CompositeType retryStatusType;
+    private static CompositeType retransmissionStatusType;
 
     private RMEndpoint endpoint;
     
@@ -101,11 +95,11 @@ public class ManagedRMEndpoint implements ManagedComponent {
                                                         DESTINATION_SEQUENCE_DESCRIPTIONS,
                                                         DESTINATION_SEQUENCE_TYPES);
 
-            retryStatusType = new CompositeType("retryStatus",
-                                                "retryStatus",
-                                                RETRY_STATUS_NAMES,
-                                                RETRY_STATUS_DESCRIPTIONS,
-                                                RETRY_STATUS_TYPES);
+            retransmissionStatusType = new CompositeType("retransmissionStatus",
+                                                         "retransmissionStatus",
+                                                         RETRANSMISSION_STATUS_NAMES,
+                                                         RETRANSMISSION_STATUS_DESCRIPTIONS,
+                                                         RETRANSMISSION_STATUS_TYPES);
             
         } catch (OpenDataException e) {
             // ignore and handle it later
@@ -124,39 +118,29 @@ public class ManagedRMEndpoint implements ManagedComponent {
     }
 
     @ManagedOperation(description = "Total Number of Queued Messages")
-    @ManagedOperationParameters({
-        @ManagedOperationParameter(name = "outbound", description = "The outbound direction") 
-    })
-    public int getQueuedMessageTotalCount(boolean outbound) {
-        if (outbound) {
-            return endpoint.getManager().getRetransmissionQueue().countUnacknowledged(); 
-        } else {
-//            return endpoint.getManager().getRedeliveryQueue().countUndelivered();
-            return 0;
+    public int getQueuedMessageTotalCount() {
+        Source source = endpoint.getSource();
+        RetransmissionQueue queue = endpoint.getManager().getRetransmissionQueue();
+        int count = 0;
+        for (SourceSequence ss : source.getAllSequences()) {
+            count += queue.countUnacknowledged(ss);
         }
+
+        return count;
     }
 
     @ManagedOperation(description = "Number of Queued Messages")
     @ManagedOperationParameters({
-        @ManagedOperationParameter(name = "sequenceId", description = "The sequence identifier"), 
-        @ManagedOperationParameter(name = "outbound", description = "The outbound direction") 
+        @ManagedOperationParameter(name = "sequenceId", description = "The sequence identifier") 
     })
-    public int getQueuedMessageCount(String sid, boolean outbound) {
+    public int getQueuedMessageCount(String sid) {
         RMManager manager = endpoint.getManager();
-        if (outbound) {
-            SourceSequence ss = getSourceSeq(sid);
-            if (null == ss) {
-                throw new IllegalArgumentException("no sequence");
-            }
-            return manager.getRetransmissionQueue().countUnacknowledged(ss);
-        } else {
-//            DestinationSequence ds = getDestinationSeq(sid);
-//            if (null == ds) {
-//                throw new IllegalArgumentException("no sequence");
-//            }
-//            return manager.getRedeliveryQueue().countUndelivered(ds);
-            return 0;
+        SourceSequence ss = getSourceSeq(sid);
+        if (null == ss) {
+            throw new IllegalArgumentException("no sequence");
         }
+
+        return manager.getRetransmissionQueue().countUnacknowledged(ss);
     }
 
     @ManagedOperation(description = "List of UnAcknowledged Message Numbers")
@@ -251,8 +235,8 @@ public class ManagedRMEndpoint implements ManagedComponent {
             throw new IllegalArgumentException("no sequence");
         }
         RetransmissionQueue rq = endpoint.getManager().getRetransmissionQueue();
-        RetryStatus rs = rq.getRetransmissionStatus(ss, num);
-        return getRetryStatusProperties(num, rs);
+        RetransmissionStatus rs = rq.getRetransmissionStatus(ss, num);
+        return getRetransmissionStatusProperties(num, rs);
     }
 
     @ManagedOperation(description = "Retransmission Statuses")
@@ -265,66 +249,16 @@ public class ManagedRMEndpoint implements ManagedComponent {
             throw new IllegalArgumentException("no sequence");
         }
         RetransmissionQueue rq = endpoint.getManager().getRetransmissionQueue();
-        Map<Long, RetryStatus> rsmap = rq.getRetransmissionStatuses(ss);
+        Map<Long, RetransmissionStatus> rsmap = rq.getRetransmissionStatuses(ss);
 
         CompositeData[] rsps = new CompositeData[rsmap.size()];
         int i = 0;
-        for (Map.Entry<Long, RetryStatus> rs : rsmap.entrySet()) {
-            rsps[i++] = getRetryStatusProperties(rs.getKey(), rs.getValue());
+        for (Map.Entry<Long, RetransmissionStatus> rs : rsmap.entrySet()) {
+            rsps[i++] = getRetransmissionStatusProperties(rs.getKey(), rs.getValue());
         }
         return rsps;
     }
 
-//     @ManagedOperation(description = "Redelivery Status")
-//     @ManagedOperationParameters({
-//         @ManagedOperationParameter(name = "sequenceId", description = "The sequence identifier"),
-//         @ManagedOperationParameter(name = "messageNumber", description = "The message number")
-//     })
-//     public CompositeData getRedeliveryStatus(String sid, long num) throws JMException {
-//         DestinationSequence ds = getDestinationSeq(sid);
-//         if (null == ds) {
-//             throw new IllegalArgumentException("no sequence");
-//         }
-//         RedeliveryQueue rq = endpoint.getManager().getRedeliveryQueue();
-//         RetryStatus rs = rq.getRedeliveryStatus(ds, num);
-//         return getRetryStatusProperties(num, rs);
-//     }
-
-//    @ManagedOperation(description = "Redelivery Statuses")
-//     @ManagedOperationParameters({
-//         @ManagedOperationParameter(name = "sequenceId", description = "The sequence identifier")
-//     })
-//     public CompositeData[] getRedeliveryStatuses(String sid) throws JMException {
-//         DestinationSequence ds = getDestinationSeq(sid);
-//         if (null == ds) {
-//             throw new IllegalArgumentException("no sequence");
-//         }
-//         RedeliveryQueue rq = endpoint.getManager().getRedeliveryQueue();
-//         Map<Long, RetryStatus> rsmap = rq.getRedeliveryStatuses(ds);
-//
-//         CompositeData[] rsps = new CompositeData[rsmap.size()];
-//         int i = 0;
-//         for (Map.Entry<Long, RetryStatus> rs : rsmap.entrySet()) {
-//             rsps[i++] = getRetryStatusProperties(rs.getKey(), rs.getValue());
-//         }
-//         return rsps;
-//     }
-
-//     @ManagedOperation(description = "List of UnDelivered Message Numbers")
-//     @ManagedOperationParameters({
-//         @ManagedOperationParameter(name = "sequenceId", description = "The sequence identifier") 
-//     })
-//     public Long[] getUnDeliveredMessageIdentifiers(String sid) {
-//         RedeliveryQueue rq = endpoint.getManager().getRedeliveryQueue();
-//         DestinationSequence ds = getDestinationSeq(sid);
-//         if (null == ds) {
-//             throw new IllegalArgumentException("no sequence");
-//         }
-//        
-//         List<Long> numbers = rq.getUndeliveredMessageNumbers(ds);
-//         return numbers.toArray(new Long[numbers.size()]);
-//     }
-
     @ManagedOperation(description = "List of Source Sequence IDs")
     @ManagedOperationParameters({
         @ManagedOperationParameter(name = "expired", description = "The expired sequences included") 
@@ -378,32 +312,6 @@ public class ManagedRMEndpoint implements ManagedComponent {
         rq.resume(ss);
     }
     
-//     @ManagedOperation(description = "Suspend Redelivery Queue")
-//     @ManagedOperationParameters({
-//         @ManagedOperationParameter(name = "sequenceId", description = "The sequence identifier") 
-//     })
-//     public void suspendDestinationQueue(String sid) throws JMException {
-//         DestinationSequence ds = getDestinationSeq(sid);
-//         if (null == ds) {
-//             throw new IllegalArgumentException("no sequence");
-//         }
-//         RedeliveryQueue rq = endpoint.getManager().getRedeliveryQueue();
-//         rq.suspend(ds);
-//     }
-    
-//     @ManagedOperation(description = "Resume Redelivery Queue")
-//     @ManagedOperationParameters({
-//         @ManagedOperationParameter(name = "sequenceId", description = "The sequence identifier") 
-//     })
-//     public void resumeDestinationQueue(String sid) throws JMException {
-//         DestinationSequence ds = getDestinationSeq(sid);
-//         if (null == ds) {
-//             throw new JMException("no source sequence");
-//         }
-//         RedeliveryQueue rq = endpoint.getManager().getRedeliveryQueue();
-//         rq.resume(ds);
-//     }
-    
     @ManagedOperation(description = "Current Source Sequence Properties")
     public CompositeData getCurrentSourceSequence() throws JMException {
         Source source = endpoint.getSource();
@@ -451,6 +359,7 @@ public class ManagedRMEndpoint implements ManagedComponent {
         return sps.toArray(new CompositeData[sps.size()]);
     }
     
+    
     @ManagedOperation(description = "Destination Sequence Properties")
     @ManagedOperationParameters({
         @ManagedOperationParameter(name = "sequenceId", description = "The destination identifier") 
@@ -487,43 +396,6 @@ public class ManagedRMEndpoint implements ManagedComponent {
         return destination.getSequence(identifier);
     }
 
-    @ManagedOperation(description = "Remove Source Sequence")
-    @ManagedOperationParameters({
-        @ManagedOperationParameter(name = "sequenceId", description = "The destination identifier") 
-    })
-    public void removeSourceSequence(String sid) throws JMException {
-        SourceSequence ss = getSourceSeq(sid);
-        if (null == ss) {
-            throw new JMException("no source sequence");
-        }
-        //TODO use cancel insted of suspend
-        RetransmissionQueue rq = endpoint.getManager().getRetransmissionQueue();
-        rq.suspend(ss);
-        ss.getSource().removeSequence(ss);
-    }
-
-    @ManagedOperation(description = "Remove Destination Sequence")
-    @ManagedOperationParameters({
-        @ManagedOperationParameter(name = "sequenceId", description = "The destination identifier") 
-    })
-    public void removeDestinationSequence(String sid) throws JMException {
-        DestinationSequence ds = getDestinationSeq(sid);
-        if (null == ds) {
-            throw new JMException("no source sequence");
-        }
-        //TODO use cancel insted of suspend
-//         RedeliveryQueue rq = endpoint.getManager().getRedeliveryQueue();
-//         rq.suspend(ds);
-        ds.getDestination().removeSequence(ds);
-    }
-    
-    private static String getAddressValue(EndpointReferenceType epr) {
-        if (null != epr && null != epr.getAddress()) {
-            return epr.getAddress().getValue();
-        }
-        return null;
-    }
-    
     private CompositeData getSourceSequenceProperties(SourceSequence ss) throws JMException {
         if (null == ss) {
             throw new IllegalArgumentException("no sequence");
@@ -532,9 +404,7 @@ public class ManagedRMEndpoint implements ManagedComponent {
         Object[] ssv = new Object[]{ss.getIdentifier().getValue(), ss.getCurrentMessageNr(), 
                                     ss.getExpires(), ss.isLastMessage(),
                                     manager.getRetransmissionQueue().countUnacknowledged(ss),
-                                    getAddressValue(ss.getTarget()),
-                                    ss.getProtocol().getWSRMNamespace(),
-                                    ss.getProtocol().getWSANamespace()};
+                                    ss.getTarget().getAddress().getValue()};
         
         CompositeData ssps = new CompositeDataSupport(sourceSequenceType, 
                                                       SOURCE_SEQUENCE_NAMES, ssv);
@@ -547,22 +417,22 @@ public class ManagedRMEndpoint implements ManagedComponent {
         }
         Object[] dsv = new Object[]{ds.getIdentifier().getValue(), ds.getLastMessageNumber(), 
                                     ds.getCorrelationID(),
-                                    getAddressValue(ds.getAcksTo()),
-                                    ds.getProtocol().getWSRMNamespace(),
-                                    ds.getProtocol().getWSANamespace()};
+                                    ds.getAcksTo().getAddress().getValue()};
         
         CompositeData dsps = new CompositeDataSupport(destinationSequenceType, 
                                                       DESTINATION_SEQUENCE_NAMES, dsv);
         return dsps;
     }
     
-    private CompositeData getRetryStatusProperties(long num, RetryStatus rs) throws JMException {
+    private CompositeData getRetransmissionStatusProperties(long num, 
+                                                            RetransmissionStatus rs) throws JMException {
         CompositeData rsps = null;
         if (null != rs) {
-            Object[] rsv = new Object[] {num, rs.getRetries(), rs.getMaxRetries(), rs.getPrevious(), 
+            Object[] rsv = new Object[] {num, rs.getResends(), rs.getPrevious(), 
                                          rs.getNext(), rs.getNextInterval(),
                                          rs.getBackoff(), rs.isPending(), rs.isSuspended()};
-            rsps = new CompositeDataSupport(retryStatusType, RETRY_STATUS_NAMES, rsv);
+            rsps = new CompositeDataSupport(retransmissionStatusType,
+                                            RETRANSMISSION_STATUS_NAMES, rsv);
         }
         return rsps;
     }
@@ -589,44 +459,5 @@ public class ManagedRMEndpoint implements ManagedComponent {
         return endpoint.getLastControlMessage() == 0L ? null 
             : new Date(endpoint.getLastControlMessage());
     }
-
-    @ManagedAttribute(description = "Number of Outbound Queued Messages", currencyTimeLimit = 10)
-    public int getQueuedMessagesOutboundCount() {
-        return endpoint.getManager().getRetransmissionQueue().countUnacknowledged();
-    }
-
-//    @ManagedAttribute(description = "Number of Outbound Completed Messages", currencyTimeLimit = 10)
-//    public int getCompletedMessagesOutboundCount() {
-//        return endpoint.getManager().countCompleted();
-//    }
-
-//    @ManagedAttribute(description = "Number of Inbound Queued Messages", currencyTimeLimit = 10)
-//    public int getQueuedMessagesInboundCount() {
-//        return endpoint.getManager().getRedeliveryQueue().countUndelivered();
-//    }
-
-//    @ManagedAttribute(description = "Number of Inbound Completed Messages", currencyTimeLimit = 10)
-//    public int getCompletedMessagesInboundCount() {
-//        return endpoint.getManager().countCompleted();
-//    }
-
-    @ManagedAttribute(description = "Number of Processing Source Sequences", currencyTimeLimit = 10)
-    public int getProcessingSourceSequenceCount() {
-        return endpoint.getProcessingSourceSequenceCount();
-    }
-     
-    @ManagedAttribute(description = "Number of Completed Source Sequences", currencyTimeLimit = 10)
-    public int getCompletedSourceSequenceCount() {
-        return endpoint.getCompletedSourceSequenceCount();
-    }
-
-    @ManagedAttribute(description = "Number of Processing Destination Sequences", currencyTimeLimit = 10)
-    public int getProcessingDestinationSequenceCount() {
-        return endpoint.getProcessingDestinationSequenceCount();
-    }
     
-    @ManagedAttribute(description = "Number of Completed Destination Sequences", currencyTimeLimit = 10)
-    public int getCompletedDestinationSequenceCount() {
-        return endpoint.getCompletedDestinationSequenceCount();
-    }
 }
